## Retailer positioning

### Description

The data represent consumer evaluations for a set of retailers in the Chicago area on 7 attributes. In addition to attribute evaluations the dataset contains preference ratings on a scale from 1-9 for each retailer for two pre-defined consumer segments.

### Variables

A data frame with 6 rows of data on 10 variables. All numbers are averages across respondents.

- retailer = The name of the retailer consumers evaluated
- good_value = How do you perceive the value of the product offerings by retailer X to be on a scale from 1-9?
- quality_prod = How do you perceive the quality of goods sold by retailer X to be on a scale from 1-9?
- service = How do you perceive the service offered by retailer X to be on a scale from 1-9?
- convenience = How do you perceive the convenience of shopping at retailer X to be on a scale from 1-9?
- assortment = How do you perceive the assortment at retailer X to be on a scale from 1-9?
- sophisticated = How do you perceive the sophistication of shoppers at retailer X to be on a scale from 1-9?
- cluttered = How cluttered do you perceive the shopping environment at retailer X to be on a scale from 1-9?
- segment1 = Average preference score for each retailer on a scale from 1-9 across respondents assigned to segment 1
- segment2 = Average preference score for each retailer on a scale from 1-9 across respondents assigned to segment 2
